// -*-C++-*-
/*!
 * @file  ImageInfoServiceSVC_impl.h
 * @brief Service implementation header of ImageInfoService.idl
 *
 */

#include "ImageInfoServiceSkel.h"

#ifndef IMAGEINFOSERVICESVC_IMPL_H
#define IMAGEINFOSERVICESVC_IMPL_H

#include <rtm/Manager.h> // for using 'usleep()' function

#include "imagecapture.h"

/*!
 * @class ImageInfoServiceSVC_impl
 * Example class implementing IDL interface ImageInfoService
 */
class ImageInfoServiceSVC_impl
 : public virtual POA_ImageInfoService,
   public virtual PortableServer::RefCountServantBase
{
 private:
   // Make sure all instances are built on the heap by making the
   // destructor non-public
   //virtual ~ImageInfoServiceSVC_impl();

 public:
  /*!
   * @brief standard constructor
   */
   ImageInfoServiceSVC_impl();
  /*!
   * @brief destructor
   */
   virtual ~ImageInfoServiceSVC_impl();

   // attributes and operations
   CORBA::Short getImageWidth()
	   throw (CORBA::SystemException);
   CORBA::Short getImageHeight()
	   throw (CORBA::SystemException);
   CORBA::Short getPixelFormat()
	   throw (CORBA::SystemException);

private:
   // image informations
	short _width, _height, _pixel;
public:
	// set image informations
	inline void setImageWidth(short width){
		_width = width;
	}
	inline void setImageHeight(short height){
		_height = height;
	}
	inline void setImagePixelFormat(short pixel){
		_pixel = pixel;
	}

	// lock/unlock service port
private:
	// true(lock) / false(unlock)
	bool _getImageWidthLock;
	bool _getImageHeightLock;
	bool _getPixelFormatLock;
public:
	void lock_getImageWidthLock(){_getImageWidthLock=true;}
	void unlock_getImageWidthLock(){_getImageWidthLock=false;}
	void lock_getImageHeightLock(){_getImageHeightLock=true;}
	void unlock_getImageHeightLock(){_getImageHeightLock=false;}
	void lock_getPixelFormatLock(){_getPixelFormatLock=true;}
	void unlock_getPixelFormatLock(){_getPixelFormatLock=false;}
};



#endif // IMAGEINFOSERVICESVC_IMPL_H


